@@ -58,43 +58,42 @@
 #define MAX_SASL_PAYLOAD_LEN 1024
 
 
-static POOL_STATUS pool_send_backend_key_data(POOL_CONNECTION * frontend, int pid, int key, int protoMajor);
-static int	do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth, int protoMajor);
-static void pool_send_auth_fail(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp);
-static int do_md5(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth, int protoMajor,
-	   char *storedPassword, PasswordType passwordType);
-static void send_md5auth_request(POOL_CONNECTION * frontend, int protoMajor, char *salt);
-static int	read_password_packet(POOL_CONNECTION * frontend, int protoMajor, char *password, int *pwdSize);
-static int	send_password_packet(POOL_CONNECTION * backend, int protoMajor, char *password);
-static int	send_auth_ok(POOL_CONNECTION * frontend, int protoMajor);
-static void sendAuthRequest(POOL_CONNECTION * frontend, int protoMajor, int32 auth_req_type, char *extradata, int extralen);
-static long PostmasterRandom(void);
+static void pool_send_backend_key_data(POOL_CONNECTION *frontend, int pid,
+									   char *key, int32 keylen, int protoMajor);
+static int	do_clear_text_password(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth, int protoMajor);
+static void pool_send_auth_fail(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp);
+static int	do_md5(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth, int protoMajor,
+				   char *storedPassword, PasswordType passwordType);
+static void send_md5auth_request(POOL_CONNECTION *frontend, int protoMajor, char *salt);
+static int	read_password_packet(POOL_CONNECTION *frontend, int protoMajor, char *password, int *pwdSize);
+static int	send_password_packet(POOL_CONNECTION *backend, int protoMajor, char *password);
+static int	send_auth_ok(POOL_CONNECTION *frontend, int protoMajor);
+static void sendAuthRequest(POOL_CONNECTION *frontend, int protoMajor, int32 auth_req_type, char *extradata, int extralen);
 
-static int	pg_SASL_continue(POOL_CONNECTION * backend, char *payload, int payloadlen, void *sasl_state, bool final);
-static void *pg_SASL_init(POOL_CONNECTION * backend, char *payload, int payloadlen, char *username, char *storedPassword);
-static bool do_SCRAM(POOL_CONNECTION * frontend, POOL_CONNECTION * backend, int protoMajor, int message_length,
-		 char *username, char *storedPassword, PasswordType passwordType);
-static void authenticate_frontend_md5(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth, int protoMajor);
-static void authenticate_frontend_cert(POOL_CONNECTION * frontend);
-static void authenticate_frontend_SCRAM(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth);
-static void authenticate_frontend_clear_text(POOL_CONNECTION * frontend);
-static bool get_auth_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth,
-				  char **password, PasswordType *passwordType);
+static int	pg_SASL_continue(POOL_CONNECTION *backend, char *payload, int payloadlen, void *sasl_state, bool final);
+static void *pg_SASL_init(POOL_CONNECTION *backend, char *payload, int payloadlen, char *username, char *storedPassword);
+static bool do_SCRAM(POOL_CONNECTION *frontend, POOL_CONNECTION *backend, int protoMajor, int message_length,
+					 char *username, char *storedPassword, PasswordType passwordType);
+static void authenticate_frontend_md5(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth, int protoMajor);
+static void authenticate_frontend_cert(POOL_CONNECTION *frontend);
+static void authenticate_frontend_SCRAM(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth);
+static void authenticate_frontend_clear_text(POOL_CONNECTION *frontend);
+static bool get_auth_password(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth,
+							  char **password, PasswordType *passwordType);
+static void ProcessNegotiateProtocol(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp);
 
 /*
  * Do authentication. Assuming the only caller is
  * make_persistent_db_connection().
  */
 void
-connection_do_auth(POOL_CONNECTION_POOL_SLOT * cp, char *password)
+connection_do_auth(POOL_CONNECTION_POOL_SLOT *cp, char *password)
 {
 	char		kind;
 	int			length;
 	int			auth_kind;
 	char		state;
-	char	   *p;
-	int			pid,
-				key;
+	int			pid;
 	bool		keydata_done;
 
 	/*
@@ -244,6 +243,9 @@ connection_do_auth(POOL_CONNECTION_POOL_SLOT * cp, char *password)
 
 		switch (kind)
 		{
+				char	   *p;
+				int32		keylen;
+
 			case 'K':			/* backend key data */
 				keydata_done = true;
 				ereport(DEBUG1,
@@ -251,12 +253,14 @@ connection_do_auth(POOL_CONNECTION_POOL_SLOT * cp, char *password)
 
 				/* read message length */
 				pool_read_with_error(cp->con, &length, sizeof(length), "message length for authentication kind 'K'");
-				if (ntohl(length) != 12)
+				length = ntohl(length);
+				keylen = length - sizeof(int32) - sizeof(int32);
+				if (keylen > MAX_CANCELKEY_LENGTH)
 				{
 					ereport(ERROR,
 							(errmsg("failed to authenticate"),
-							 errdetail("invalid backend key data length. received %d bytes when expecting 12 bytes"
-									   ,ntohl(length))));
+							 errdetail("invalid backend key data length. received %d bytes exceeding %d",
+									   ntohl(length), MAX_CANCELKEY_LENGTH)));
 				}
 
 				/* read pid */
@@ -264,9 +268,9 @@ connection_do_auth(POOL_CONNECTION_POOL_SLOT * cp, char *password)
 				cp->pid = pid;
 
 				/* read key */
-				pool_read_with_error(cp->con, &key, sizeof(key),
-									 "key for authentication kind 'K'");
-				cp->key = key;
+				keylen = length - sizeof(int32) - sizeof(int32);
+				p = pool_read2(cp->con, keylen);
+				memcpy(cp->key, p, keylen);
 				break;
 
 			case 'Z':			/* Ready for query */
@@ -328,21 +332,23 @@ connection_do_auth(POOL_CONNECTION_POOL_SLOT * cp, char *password)
  * 0.
 */
 int
-pool_do_auth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
+pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 {
 	signed char kind;
 	int			pid;
-	int			key;
 	int			protoMajor;
 	int			length;
 	int			authkind;
 	int			i;
 	int			message_length = 0;
 	StartupPacket *sp;
-
+	int32		keylen;			/* cancel key length */
+	char		cancel_key[MAX_CANCELKEY_LENGTH];
+	char	   *p;
 
 	protoMajor = MAIN_CONNECTION(cp)->sp->major;
 
+read_kind:
 	kind = pool_read_kind(cp);
 	if (kind < 0)
 		ereport(ERROR,
@@ -366,6 +372,12 @@ pool_do_auth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 				 errdetail("backend response with kind \'E\' when expecting \'R\'"),
 				 errhint("This issue can be caused by version mismatch (current version %d)", protoMajor)));
 	}
+	else if (kind == 'v')
+	{
+		/* NegotiateProtocolVersion received */
+		ProcessNegotiateProtocol(frontend, cp);
+		goto read_kind;
+	}
 	else if (kind != 'R')
 		ereport(ERROR,
 				(errmsg("backend authentication failed"),
@@ -472,9 +484,8 @@ pool_do_auth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 							  &password, &passwordType) == false)
 		{
 			/*
-			 * We do not have any password, we can still get the password
-			 * from client using plain text authentication if it is
-			 * allowed by user
+			 * We do not have any password, we can still get the password from
+			 * client using plain text authentication if it is allowed by user
 			 */
 			if (frontend->pool_hba == NULL && pool_config->allow_clear_text_frontend_auth)
 			{
@@ -598,8 +609,11 @@ pool_do_auth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 
 		}
 
-		send_auth_ok(frontend, protoMajor);
-		authkind = 0;
+		if (kind == 'R')
+		{
+			send_auth_ok(frontend, protoMajor);
+			authkind = 0;
+		}
 	}
 
 	else
@@ -712,17 +726,23 @@ pool_do_auth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 	}
 
 	/*
-	 * message length (V3 only)
+	 * Read BackendKeyData message length.
 	 */
 	if (protoMajor == PROTO_MAJOR_V3)
 	{
-		if ((length = pool_read_message_length(cp)) != 12)
+		length = pool_read_message_length(cp);
+		keylen = length - sizeof(int32) - sizeof(int32);
+		if (keylen > MAX_CANCELKEY_LENGTH)
 		{
 			ereport(ERROR,
-					(errmsg("authentication failed"),
-					 errdetail("invalid messages length(%d) for BackendKeyData", length)));
+					(errcode(ERRCODE_PROTOCOL_VIOLATION),
+					 errmsg("cancel key length exceeds 256 bytes")));
 		}
 	}
+	else
+		keylen = 4;
+
+	elog(DEBUG1, "cancel key length: %d", keylen);
 
 	/*
 	 * OK, read pid and secret key
@@ -748,16 +768,29 @@ pool_do_auth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 			CONNECTION_SLOT(cp, i)->pid = cp->info[i].pid = pid;
 
 			/* read key */
-			if (pool_read(CONNECTION(cp, i), &key, sizeof(key)) < 0)
+			p = pool_read2(CONNECTION(cp, i), keylen);
+			if (p == NULL)
 			{
 				ereport(ERROR,
 						(errmsg("authentication failed"),
-						 errdetail("failed to read key in slot %d", i)));
+						 errdetail("failed to read key of length: %d in slot %d", keylen, i)));
 			}
-			CONNECTION_SLOT(cp, i)->key = cp->info[i].key = key;
+			memcpy(CONNECTION_SLOT(cp, i)->key, p, keylen);
+			memcpy(cp->info[i].key, p, keylen);
+			memcpy(cancel_key, p, keylen);
+			CONNECTION_SLOT(cp, i)->keylen = cp->info[i].keylen = keylen;
 
 			cp->info[i].major = sp->major;
-			cp->info[i].minor = sp->minor;
+
+			/*
+			 * If NegotiateProtocol message has been received, set the minor
+			 * version. Othewise use the version in the StartupMessage.
+			 */
+			if (CONNECTION_SLOT(cp, i)->nplen > 0)
+				cp->info[i].minor = CONNECTION_SLOT(cp, i)->negotiated_minor;
+			else
+				cp->info[i].minor = sp->minor;
+
 			strlcpy(cp->info[i].database, sp->database, sizeof(cp->info[i].database));
 			strlcpy(cp->info[i].user, sp->user, sizeof(cp->info[i].user));
 			cp->info[i].counter = 1;
@@ -772,24 +805,42 @@ pool_do_auth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 				(errmsg("authentication failed"),
 				 errdetail("pool_do_auth: all backends are down")));
 	}
-	if (pool_send_backend_key_data(frontend, pid, key, protoMajor))
-		ereport(ERROR,
-				(errmsg("authentication failed"),
-				 errdetail("failed to send backend data to frontend")));
+
+	/*
+	 * We send the BackendKeyData to frontend, which belongs to the last
+	 * backend in the backend group.
+	 */
+	pool_send_backend_key_data(frontend, pid, cancel_key,
+							   MAIN_CONNECTION(cp)->keylen, protoMajor);
 	return 0;
 }
 
 /*
-* do re-authentication for reused connection. if success return 0 otherwise throws ereport.
+* do re-authentication for reused connection. if success return 0 otherwise
+* throws ereport.
 */
 int
-pool_do_reauth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
+pool_do_reauth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 {
 	int			protoMajor;
 	int			msglen;
+	POOL_CONNECTION_POOL_SLOT *sp;
 
 	protoMajor = MAJOR(cp);
 
+	/*
+	 * If NegotiateProtocolMsg has been received from backend, forward it to
+	 * frontend. If the frontend dislike it, it will disconnect the
+	 * connection. Otherwise it will silently continue.
+	 */
+	sp = CONNECTION_SLOT(cp, MAIN_NODE_ID);
+	if (protoMajor == PROTO_MAJOR_V3 && sp->nplen > 0)
+	{
+		elog(DEBUG1, "negotiateProtocol message is forwarded to frontend at reauth");
+		pool_write_and_flush(frontend, sp->negotiateProtocolMsg,
+							 sp->nplen);
+	}
+
 	/*
 	 * if hba is enabled we would already have passed authentication
 	 */
@@ -823,6 +874,9 @@ pool_do_reauth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 		}
 	}
 
+	/*
+	 * Send auth ok
+	 */
 	pool_write(frontend, "R", 1);
 
 	if (protoMajor == PROTO_MAJOR_V3)
@@ -833,7 +887,11 @@ pool_do_reauth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 
 	msglen = htonl(0);
 	pool_write_and_flush(frontend, &msglen, sizeof(msglen));
-	pool_send_backend_key_data(frontend, MAIN_CONNECTION(cp)->pid, MAIN_CONNECTION(cp)->key, protoMajor);
+
+	/* send BackendKeyData */
+	pool_send_backend_key_data(frontend, MAIN_CONNECTION(cp)->pid, MAIN_CONNECTION(cp)->key,
+							   MAIN_CONNECTION(cp)->keylen, protoMajor);
+
 	return 0;
 }
 
@@ -841,7 +899,7 @@ pool_do_reauth(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 * send authentication failure message text to frontend
 */
 static void
-pool_send_auth_fail(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
+pool_send_auth_fail(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 {
 	int			messagelen;
 	char	   *errmessage;
@@ -863,33 +921,31 @@ pool_send_auth_fail(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * cp)
 }
 
 /*
- * Send backend key data to frontend. if success return 0 otherwise non 0.
+ * Send backend key data to frontend.
  */
-static POOL_STATUS pool_send_backend_key_data(POOL_CONNECTION * frontend, int pid, int key, int protoMajor)
+static void
+pool_send_backend_key_data(POOL_CONNECTION *frontend, int pid,
+						   char *key, int32 keylen, int protoMajor)
 {
 	char		kind;
-	int			len;
+	int32		len;
 
 	/* Send backend key data */
 	kind = 'K';
 	pool_write(frontend, &kind, 1);
 	if (protoMajor == PROTO_MAJOR_V3)
 	{
-		len = htonl(12);
+		len = htonl(sizeof(int32) + sizeof(int32) + keylen);
 		pool_write(frontend, &len, sizeof(len));
 	}
 	ereport(DEBUG1,
-			(errmsg("sending backend key data"),
-			 errdetail("send pid %d to frontend", ntohl(pid))));
-
+			(errmsg("sending backend key data")));
 	pool_write(frontend, &pid, sizeof(pid));
-	pool_write_and_flush(frontend, &key, sizeof(key));
-
-	return 0;
+	pool_write_and_flush(frontend, key, keylen);
 }
 
 static void
-authenticate_frontend_clear_text(POOL_CONNECTION * frontend)
+authenticate_frontend_clear_text(POOL_CONNECTION *frontend)
 {
 	static int	size;
 	char		password[MAX_PASSWORD_SIZE];
@@ -976,7 +1032,7 @@ authenticate_frontend_clear_text(POOL_CONNECTION * frontend)
  * perform clear text password authentication
  */
 static int
-do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth, int protoMajor)
+do_clear_text_password(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth, int protoMajor)
 {
 	static int	size;
 	char	   *pwd = NULL;
@@ -1009,17 +1065,16 @@ do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, in
 	else if (!rtn || frontend->pwd_size == 0)
 	{
 		/*
-		 * We do not have any password, we can still get the password
-		 * from client using plain text authentication if it is
-		 * allowed by user
+		 * We do not have any password, we can still get the password from
+		 * client using plain text authentication if it is allowed by user
 		 */
 
 		if (frontend->pool_hba == NULL ||
 			frontend->pool_hba->auth_method == uaPassword ||
-			pool_config->allow_clear_text_frontend_auth )
+			pool_config->allow_clear_text_frontend_auth)
 		{
 			ereport(DEBUG1,
-				(errmsg("using clear text authentication with frontend"),
+					(errmsg("using clear text authentication with frontend"),
 					 errdetail("backend is using password authentication")));
 
 			authenticate_frontend_clear_text(frontend);
@@ -1029,8 +1084,8 @@ do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, in
 			{
 				ereport(FATAL,
 						(return_code(2),
-							errmsg("clear text password authentication failed"),
-							errdetail("unable to get the password for user: \"%s\"", frontend->username)));
+						 errmsg("clear text password authentication failed"),
+						 errdetail("unable to get the password for user: \"%s\"", frontend->username)));
 			}
 		}
 	}
@@ -1100,7 +1155,7 @@ do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, in
  * password in the pool_passwd file.
  */
 static void
-authenticate_frontend_SCRAM(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth)
+authenticate_frontend_SCRAM(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth)
 {
 	void	   *scram_opaq;
 	char	   *output = NULL;
@@ -1115,7 +1170,7 @@ authenticate_frontend_SCRAM(POOL_CONNECTION * backend, POOL_CONNECTION * fronten
 	PasswordType storedPasswordType = PASSWORD_TYPE_UNKNOWN;
 	char	   *storedPassword = NULL;
 
-	if (get_auth_password(backend, frontend, reauth,&storedPassword, &storedPasswordType) == false)
+	if (get_auth_password(backend, frontend, reauth, &storedPassword, &storedPasswordType) == false)
 	{
 		ereport(FATAL,
 				(return_code(2),
@@ -1284,7 +1339,7 @@ authenticate_frontend_SCRAM(POOL_CONNECTION * backend, POOL_CONNECTION * fronten
  * Authenticate frontend using pool_hba.conf
  */
 void
-authenticate_frontend(POOL_CONNECTION * frontend)
+authenticate_frontend(POOL_CONNECTION *frontend)
 {
 	switch (frontend->pool_hba->auth_method)
 	{
@@ -1322,7 +1377,7 @@ authenticate_frontend(POOL_CONNECTION * frontend)
 
 #ifdef USE_SSL
 static void
-authenticate_frontend_cert(POOL_CONNECTION * frontend)
+authenticate_frontend_cert(POOL_CONNECTION *frontend)
 {
 	if (frontend->client_cert_loaded == true && frontend->cert_cn)
 	{
@@ -1349,7 +1404,7 @@ authenticate_frontend_cert(POOL_CONNECTION * frontend)
 }
 #else
 static void
-authenticate_frontend_cert(POOL_CONNECTION * frontend)
+authenticate_frontend_cert(POOL_CONNECTION *frontend)
 {
 	ereport(ERROR,
 			(errmsg("CERT authentication failed"),
@@ -1358,7 +1413,7 @@ authenticate_frontend_cert(POOL_CONNECTION * frontend)
 #endif
 
 static void
-authenticate_frontend_md5(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth, int protoMajor)
+authenticate_frontend_md5(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth, int protoMajor)
 {
 	char		salt[4];
 	static int	size;
@@ -1370,7 +1425,7 @@ authenticate_frontend_md5(POOL_CONNECTION * backend, POOL_CONNECTION * frontend,
 	PasswordType storedPasswordType = PASSWORD_TYPE_UNKNOWN;
 	char	   *storedPassword = NULL;
 
-	if (get_auth_password(backend, frontend, reauth,&storedPassword, &storedPasswordType) == false)
+	if (get_auth_password(backend, frontend, reauth, &storedPassword, &storedPasswordType) == false)
 	{
 		ereport(FATAL,
 				(return_code(2),
@@ -1446,7 +1501,7 @@ authenticate_frontend_md5(POOL_CONNECTION * backend, POOL_CONNECTION * frontend,
  * it.
  */
 static bool
-get_auth_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth,
+get_auth_password(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth,
 				  char **password, PasswordType *passwordType)
 {
 	/* First preference is to use the pool_passwd file */
@@ -1495,7 +1550,7 @@ get_auth_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int rea
  * perform MD5 authentication
  */
 static int
-do_md5(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth, int protoMajor,
+do_md5(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reauth, int protoMajor,
 	   char *storedPassword, PasswordType passwordType)
 {
 	char		salt[4];
@@ -1612,7 +1667,7 @@ do_md5(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, int reauth, int pr
  * Send an authentication request packet to the frontend.
  */
 static void
-sendAuthRequest(POOL_CONNECTION * frontend, int protoMajor, int32 auth_req_type, char *extradata, int extralen)
+sendAuthRequest(POOL_CONNECTION *frontend, int protoMajor, int32 auth_req_type, char *extradata, int extralen)
 {
 	int			kind = htonl(auth_req_type);
 
@@ -1635,7 +1690,7 @@ sendAuthRequest(POOL_CONNECTION * frontend, int protoMajor, int32 auth_req_type,
  * Send md5 authentication request packet to frontend
  */
 static void
-send_md5auth_request(POOL_CONNECTION * frontend, int protoMajor, char *salt)
+send_md5auth_request(POOL_CONNECTION *frontend, int protoMajor, char *salt)
 {
 	sendAuthRequest(frontend, protoMajor, AUTH_REQ_MD5, salt, 4);
 }
@@ -1645,7 +1700,7 @@ send_md5auth_request(POOL_CONNECTION * frontend, int protoMajor, char *salt)
  * Read password packet from frontend
  */
 static int
-read_password_packet(POOL_CONNECTION * frontend, int protoMajor, char *password, int *pwdSize)
+read_password_packet(POOL_CONNECTION *frontend, int protoMajor, char *password, int *pwdSize)
 {
 	int			size;
 
@@ -1698,7 +1753,7 @@ read_password_packet(POOL_CONNECTION * frontend, int protoMajor, char *password,
  * "password" must be null-terminated.
  */
 static int
-send_password_packet(POOL_CONNECTION * backend, int protoMajor, char *password)
+send_password_packet(POOL_CONNECTION *backend, int protoMajor, char *password)
 {
 	int			size;
 	int			len;
@@ -1754,7 +1809,7 @@ send_password_packet(POOL_CONNECTION * backend, int protoMajor, char *password)
  * Send auth ok to frontend
  */
 static int
-send_auth_ok(POOL_CONNECTION * frontend, int protoMajor)
+send_auth_ok(POOL_CONNECTION *frontend, int protoMajor)
 {
 	int			msglen;
 
@@ -1771,27 +1826,16 @@ send_auth_ok(POOL_CONNECTION * frontend, int protoMajor)
 	return 0;
 }
 
-
+/*
+ * Generate random bytes
+ */
 void
 pool_random(void *buf, size_t len)
 {
-	int			ret = 0;
-#ifdef USE_SSL
-	ret = RAND_bytes(buf, len);
-#endif
-	/* if RND_bytes fails or not present use the old technique */
-	if (ret == 0)
-	{
-		int			i;
-		char	   *ptr = buf;
-
-		for (i = 0; i < len; i++)
-		{
-			long		rand = PostmasterRandom();
-
-			ptr[i] = (rand % 255) + 1;
-		}
-	}
+	if (!pg_strong_random(buf, len))
+		ereport(ERROR,
+				(errcode(ERRCODE_INTERNAL_ERROR),
+				 errmsg("could not generate random bytes")));
 }
 
 /*
@@ -1803,47 +1847,8 @@ pool_random_salt(char *md5Salt)
 	pool_random(md5Salt, 4);
 }
 
-/*
- * PostmasterRandom
- */
-static long
-PostmasterRandom(void)
-{
-	extern struct timeval random_start_time;
-	static unsigned int random_seed = 0;
-
-	/*
-	 * Select a random seed at the time of first receiving a request.
-	 */
-	if (random_seed == 0)
-	{
-		do
-		{
-			struct timeval random_stop_time;
-
-			gettimeofday(&random_stop_time, NULL);
-
-			/*
-			 * We are not sure how much precision is in tv_usec, so we swap
-			 * the high and low 16 bits of 'random_stop_time' and XOR them
-			 * with 'random_start_time'. On the off chance that the result is
-			 * 0, we loop until it isn't.
-			 */
-			random_seed = random_start_time.tv_usec ^
-				((random_stop_time.tv_usec << 16) |
-				 ((random_stop_time.tv_usec >> 16) & 0xffff));
-		}
-		while (random_seed == 0);
-
-		srandom(random_seed);
-	}
-
-	return random();
-}
-
-
 static bool
-do_SCRAM(POOL_CONNECTION * frontend, POOL_CONNECTION * backend, int protoMajor, int message_length,
+do_SCRAM(POOL_CONNECTION *frontend, POOL_CONNECTION *backend, int protoMajor, int message_length,
 		 char *username, char *storedPassword, PasswordType passwordType)
 {
 	/* read the packet first */
@@ -1972,7 +1977,7 @@ do_SCRAM(POOL_CONNECTION * frontend, POOL_CONNECTION * backend, int protoMajor,
 }
 
 static void *
-pg_SASL_init(POOL_CONNECTION * backend, char *payload, int payloadlen, char *username, char *storedPassword)
+pg_SASL_init(POOL_CONNECTION *backend, char *payload, int payloadlen, char *username, char *storedPassword)
 {
 	char	   *initialresponse = NULL;
 	int			initialresponselen;
@@ -2075,7 +2080,7 @@ pg_SASL_init(POOL_CONNECTION * backend, char *payload, int payloadlen, char *use
  * the protocol.
  */
 static int
-pg_SASL_continue(POOL_CONNECTION * backend, char *payload, int payloadlen, void *sasl_state, bool final)
+pg_SASL_continue(POOL_CONNECTION *backend, char *payload, int payloadlen, void *sasl_state, bool final)
 {
 	char	   *output;
 	int			outputlen;
@@ -2125,3 +2130,71 @@ pg_SASL_continue(POOL_CONNECTION * backend, char *payload, int payloadlen, void
 
 	return 0;
 }
+
+/*
+ * Forward NegotiateProtocol message to frontend.
+ *
+ * When this function is called, message kind has been already read.
+ */
+static void
+ProcessNegotiateProtocol(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
+{
+	int32		len;
+	int32		savelen;
+	int32		protoMajor;
+	int32		protoMinor;
+	int32		protov;
+	bool		forwardMsg = false;
+	int			i;
+
+	elog(DEBUG1, "Forwarding NegotiateProtocol message to frontend");
+	pool_write(frontend, "v", 1);	/* forward message kind */
+	savelen = len = pool_read_int(cp);	/* message length including self */
+	pool_write(frontend, &len, 4);	/* forward message length */
+	len = ntohl(len) - 4;		/* length of rest of the message */
+	protov = pool_read_int(cp); /* read protocol version */
+	protoMajor = PG_PROTOCOL_MAJOR(ntohl(protov));	/* protocol major version */
+	protoMinor = PG_PROTOCOL_MINOR(ntohl(protov));	/* protocol minor version */
+	pool_write(frontend, &protov, 4);	/* forward protocol version */
+	elog(DEBUG1, "protocol verion offered: major: %d minor: %d", protoMajor, protoMinor);
+	len -= 4;
+	for (i = 0; i < NUM_BACKENDS; i++)
+	{
+		if (VALID_BACKEND(i))
+		{
+			POOL_CONNECTION_POOL_SLOT *sp;
+			char	   *p;
+			char	   *np;
+			Size		nplen;
+
+			p = pool_read2(CONNECTION(cp, i), len);
+			if (!forwardMsg)
+			{
+				pool_write_and_flush(frontend, p, len); /* forward rest of
+														 * message */
+				forwardMsg = true;
+			}
+			/* save negatiate protocol version */
+			sp = CONNECTION_SLOT(cp, i);
+			sp->negotiated_major = protoMajor;
+			sp->negotiated_minor = protoMinor;
+
+			/* save negatiate protocol message */
+			nplen = 1 +			/* message kind */
+				sizeof(savelen) +	/* message length */
+				sizeof(protov) +	/* protocol version */
+				len;			/* rest of message */
+			/* allocate message area */
+			sp->negotiateProtocolMsg = MemoryContextAlloc(TopMemoryContext, nplen);
+			np = sp->negotiateProtocolMsg;
+			sp->nplen = nplen;	/* set message length */
+
+			*np++ = 'v';
+			memcpy(np, &savelen, sizeof(savelen));
+			np += sizeof(savelen);
+			memcpy(np, &protov, sizeof(protov));
+			np += sizeof(protov);
+			memcpy(np, p, len);
+		}
+	}
+}
