@@ -4,7 +4,7 @@
  *	  POSTGRES error reporting/logging definitions.
  *
  *
- * Portions Copyright (c) 2003-2014, PgPool Global Development Group
+ * Portions Copyright (c) 2003-2024, PgPool Global Development Group
  * Portions Copyright (c) 1996-2013, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
@@ -121,8 +121,10 @@ typedef enum
 /* pgpool-II extension. This is same as ERROR but sets the
  * do not cache connection flag before transforming to ERROR.
  */
-#define FRONTEND_ERROR			23	/* transformed to ERROR at errstart */
-#define FRONTEND_ONLY_ERROR		24	/* this is treated as LOG message
+#define FRONTEND_DEBUG			23	/* transformed to DEBUG at errstart */
+#define FRONTEND_LOG			24	/* transformed to LOG at errstart */
+#define FRONTEND_ERROR			25	/* transformed to ERROR at errstart */
+#define FRONTEND_ONLY_ERROR		26	/* this is treated as LOG message
 									 * internally for pgpool-II but forwarded
 									 * to frontend clients just like normal
 									 * errors followed by readyForQuery
@@ -205,8 +207,9 @@ typedef enum
 
 #define TEXTDOMAIN NULL
 
+extern bool message_level_is_interesting(int elevel);
 extern bool errstart(int elevel, const char *filename, int lineno,
-		 const char *funcname, const char *domain);
+					 const char *funcname, const char *domain);
 extern void errfinish(int dummy,...);
 
 #define errcode(sqlerrcode) \
@@ -219,56 +222,56 @@ extern int	return_code(int retcode);
 extern int	get_return_code(void);
 
 extern int
-errmsg(const char *fmt,...)
+			errmsg(const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 extern int
-errmsg_internal(const char *fmt,...)
+			errmsg_internal(const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 extern int
-errmsg_plural(const char *fmt_singular, const char *fmt_plural,
-			  unsigned long n,...)
+			errmsg_plural(const char *fmt_singular, const char *fmt_plural,
+						  unsigned long n,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 4)))
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 2, 4)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 4)))
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 2, 4)));
 
 extern int
-errdetail(const char *fmt,...)
+			errdetail(const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 extern int
-errdetail_internal(const char *fmt,...)
+			errdetail_internal(const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 extern int
-errdetail_log(const char *fmt,...)
+			errdetail_log(const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 extern int
-errdetail_plural(const char *fmt_singular, const char *fmt_plural,
-				 unsigned long n,...)
+			errdetail_plural(const char *fmt_singular, const char *fmt_plural,
+							 unsigned long n,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 4)))
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 2, 4)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 4)))
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 2, 4)));
 
 extern int
-errhint(const char *fmt,...)
+			errhint(const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 /*
  * errcontext() is typically called in error context callback functions, not
@@ -282,10 +285,10 @@ __attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 extern int	set_errcontext_domain(const char *domain);
 extern int
-errcontext_msg(const char *fmt,...)
+			errcontext_msg(const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 extern int	errhidestmt(bool hide_stmt);
 
@@ -339,10 +342,10 @@ extern int	getinternalerrposition(void);
 
 extern void elog_start(const char *filename, int lineno, const char *funcname);
 extern void
-elog_finish(int elevel, const char *fmt,...)
+			elog_finish(int elevel, const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 2, 3)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 2, 3)));
 
 
 /* Support for attaching context information to error reports */
@@ -513,10 +516,10 @@ extern void set_syslog_parameters(const char *ident, int facility);
  * safely (memory context, GUC load etc)
  */
 extern void
-write_stderr(const char *fmt,...)
+			write_stderr(const char *fmt,...)
 /* This extension allows gcc to check the format string for consistency with
    the supplied arguments. */
-__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
+			__attribute__((format(PG_PRINTF_ATTRIBUTE, 1, 2)));
 
 void		shmem_exit(int code);
 void		on_exit_reset(void);
