@@ -3,7 +3,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2020	PgPool Global Development Group
+ * Copyright (c) 2003-2025	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -28,6 +28,7 @@
 #include "protocol/pool_connection_pool.h"
 #include "utils/palloc.h"
 #include "utils/memutils.h"
+#include "utils/pg_prng.h"
 #include "utils/pool_ipc.h"
 #include "utils/pool_stream.h"
 #include "utils/pool_ssl.h"
@@ -40,10 +41,12 @@
 #include "pool_config_variables.h"
 
 static int	choose_db_node_id(char *str);
-static void free_persistent_db_connection_memory(POOL_CONNECTION_POOL_SLOT * cp);
+static void free_persistent_db_connection_memory(POOL_CONNECTION_POOL_SLOT *cp);
 static void si_enter_critical_region(void);
 static void si_leave_critical_region(void);
 
+static void initialize_prng(pg_prng_state *state);
+
 /*
  * create a persistent connection
  */
@@ -61,9 +64,9 @@ make_persistent_db_connection(
 	{
 		int			protoVersion;
 		char		data[MAX_USER_AND_DATABASE];
-	}			StartupPacket_v3;
+	} StartupPacket_v3;
 
-	static StartupPacket_v3 * startup_packet;
+	static StartupPacket_v3 *startup_packet;
 	int			len,
 				len1;
 
@@ -197,8 +200,8 @@ make_persistent_db_connection_noerror(
 		 * receives an ERROR, it stops processing and terminates, which is not
 		 * good. This is problematic especially with pcp_node_info, since it
 		 * calls db_node_role(), and db_node_role() calls this function. So if
-		 * the target PostgreSQL is down, EmitErrorReport() sends ERROR message
-		 * to pcp frontend and it stops (see process_pcp_response() in
+		 * the target PostgreSQL is down, EmitErrorReport() sends ERROR
+		 * message to pcp frontend and it stops (see process_pcp_response() in
 		 * src/libs/pcp/pcp.c. To fix this, just eliminate calling
 		 * EmitErrorReport(). This will suppress ERROR message but as you can
 		 * see the comment in this function "does not ereports in case of an
@@ -218,7 +221,7 @@ make_persistent_db_connection_noerror(
  * make_persistent_db_connection and discard_persistent_db_connection.
  */
 static void
-free_persistent_db_connection_memory(POOL_CONNECTION_POOL_SLOT * cp)
+free_persistent_db_connection_memory(POOL_CONNECTION_POOL_SLOT *cp)
 {
 	if (!cp)
 		return;
@@ -242,7 +245,7 @@ free_persistent_db_connection_memory(POOL_CONNECTION_POOL_SLOT * cp)
  * make_persistent_db_connection().
  */
 void
-discard_persistent_db_connection(POOL_CONNECTION_POOL_SLOT * cp)
+discard_persistent_db_connection(POOL_CONNECTION_POOL_SLOT *cp)
 {
 	int			len;
 
@@ -271,7 +274,7 @@ discard_persistent_db_connection(POOL_CONNECTION_POOL_SLOT * cp)
  * send startup packet
  */
 void
-send_startup_packet(POOL_CONNECTION_POOL_SLOT * cp)
+send_startup_packet(POOL_CONNECTION_POOL_SLOT *cp)
 {
 	int			len;
 
@@ -299,7 +302,8 @@ pool_free_startup_packet(StartupPacket *sp)
 /*
  * Select load balancing node. This function is called when:
  * 1) client connects
- * 2) the node previously selected for the load balance node is down
+ * 2) an SQL executes (if statement_level_load_balance is enabled)
+ * 3) the node previously selected for the load balance node is down
  */
 int
 select_load_balancing_node(void)
@@ -315,7 +319,10 @@ select_load_balancing_node(void)
 	int			tmp;
 	int			no_load_balance_node_id = -2;
 	uint64		lowest_delay;
-	int 		lowest_delay_nodes[NUM_BACKENDS];
+	int			lowest_delay_nodes[NUM_BACKENDS];
+
+	/* prng state data for load balancing */
+	static pg_prng_state backsel_state;
 
 	/*
 	 * -2 indicates there's no database_redirect_preference_list. -1 indicates
@@ -324,11 +331,10 @@ select_load_balancing_node(void)
 	 */
 	int			suggested_node_id = -2;
 
-#if defined(sun) || defined(__sun)
-	r = (((double) rand()) / RAND_MAX);
-#else
-	r = (((double) random()) / RAND_MAX);
-#endif
+	/* initialize prng if necessary */
+	initialize_prng(&backsel_state);
+
+	r = pg_prng_double(&backsel_state);
 
 	/*
 	 * Check user_redirect_preference_list
@@ -437,24 +443,27 @@ select_load_balancing_node(void)
 	if (suggested_node_id >= 0)
 	{
 		/*
-		 * If pgpool is running in Streaming Replication mode and delay_threshold
-		 * and prefer_lower_delay_standby are true, we choose the least delayed
-		 * node if suggested_node is standby and delayed over delay_threshold.
+		 * If pgpool is running in Streaming Replication mode and
+		 * delay_threshold and prefer_lower_delay_standby are true, we choose
+		 * the least delayed node if suggested_node is standby and delayed
+		 * over delay_threshold.
 		 */
 		if (STREAM && pool_config->prefer_lower_delay_standby &&
 			suggested_node_id != PRIMARY_NODE_ID &&
 			check_replication_delay(suggested_node_id) < 0)
 		{
 			ereport(DEBUG1,
-				(errmsg("selecting load balance node"),
-				 errdetail("suggested backend %d is streaming delayed over delay_threshold", suggested_node_id)));
+					(errmsg("selecting load balance node"),
+					 errdetail("suggested backend %d is streaming delayed over delay_threshold", suggested_node_id)));
 
 			/*
-			 * The new load balancing node is selected from the
-			 * nodes which have the lowest delay.
+			 * The new load balancing node is selected from the nodes which
+			 * have the lowest delay.
 			 */
 			if (pool_config->delay_threshold_by_time > 0)
-				lowest_delay = pool_config->delay_threshold_by_time * 1000;	/* convert from milli seconds to micro seconds */
+				lowest_delay = pool_config->delay_threshold_by_time * 1000; /* convert from milli
+																			 * seconds to micro
+																			 * seconds */
 			else
 				lowest_delay = pool_config->delay_threshold;
 
@@ -478,7 +487,8 @@ select_load_balancing_node(void)
 					}
 					else if (lowest_delay > BACKEND_INFO(i).standby_delay)
 					{
-						int ii;
+						int			ii;
+
 						lowest_delay = BACKEND_INFO(i).standby_delay;
 						for (ii = 0; ii < NUM_BACKENDS; ii++)
 						{
@@ -490,11 +500,7 @@ select_load_balancing_node(void)
 				}
 			}
 
-#if defined(sun) || defined(__sun)
-			r = (((double) rand()) / RAND_MAX) * total_weight;
-#else
-			r = (((double) random()) / RAND_MAX) * total_weight;
-#endif
+			r = pg_prng_double(&backsel_state) * total_weight;
 
 			selected_slot = PRIMARY_NODE_ID;
 			total_weight = 0.0;
@@ -573,11 +579,7 @@ select_load_balancing_node(void)
 		}
 	}
 
-#if defined(sun) || defined(__sun)
-	r = (((double) rand()) / RAND_MAX) * total_weight;
-#else
-	r = (((double) random()) / RAND_MAX) * total_weight;
-#endif
+	r = pg_prng_double(&backsel_state) * total_weight;
 
 	total_weight = 0.0;
 	for (i = 0; i < NUM_BACKENDS; i++)
@@ -630,7 +632,8 @@ select_load_balancing_node(void)
 				}
 				else if (lowest_delay > BACKEND_INFO(i).standby_delay)
 				{
-					int ii;
+					int			ii;
+
 					lowest_delay = BACKEND_INFO(i).standby_delay;
 					for (ii = 0; ii < NUM_BACKENDS; ii++)
 					{
@@ -642,11 +645,7 @@ select_load_balancing_node(void)
 			}
 		}
 
-#if defined(sun) || defined(__sun)
-		r = (((double) rand()) / RAND_MAX) * total_weight;
-#else
-		r = (((double) random()) / RAND_MAX) * total_weight;
-#endif
+		r = pg_prng_double(&backsel_state) * total_weight;
 
 		selected_slot = PRIMARY_NODE_ID;
 
@@ -676,6 +675,27 @@ select_load_balancing_node(void)
 	return selected_slot;
 }
 
+/*
+ * initialize_prng() -
+ *
+ *	Initialize (seed) the PRNG, if not done yet in this process.
+ */
+static void
+initialize_prng(pg_prng_state *state)
+{
+	static bool prng_seed_set = false;
+	uint64		seed;
+
+	if (unlikely(!prng_seed_set))
+	{
+		/* initialize prng */
+		if (!pg_strong_random(&seed, sizeof(seed)))
+			seed = UINT64CONST(1);	/* Pick a value, as long as it spreads */
+		pg_prng_seed(state, seed);
+		prng_seed_set = true;
+	}
+}
+
 /*
  * Returns PostgreSQL version.
  * The returned PgVersion struct is in static memory.
@@ -687,17 +707,17 @@ select_load_balancing_node(void)
  *
  */
 PGVersion *
-Pgversion(POOL_CONNECTION_POOL * backend)
+Pgversion(POOL_CONNECTION_POOL *backend)
 {
 #define VERSION_BUF_SIZE	10
-	static	PGVersion	pgversion;
-	static	POOL_RELCACHE *relcache;
-	char	*result;
-	char	*p;
-	char	buf[VERSION_BUF_SIZE];
-	int		i;
-	int		major;
-	int		minor;
+	static PGVersion pgversion;
+	static POOL_RELCACHE *relcache;
+	char	   *result;
+	char	   *p;
+	char		buf[VERSION_BUF_SIZE];
+	int			i;
+	int			major;
+	int			minor;
 
 	/*
 	 * First, check local cache. If cache is set, just return it.
@@ -728,7 +748,7 @@ Pgversion(POOL_CONNECTION_POOL * backend)
 	/*
 	 * Search relcache.
 	 */
-	result = (char *)pool_search_relcache(relcache, backend, "version");
+	result = (char *) pool_search_relcache(relcache, backend, "version");
 	if (result == 0)
 	{
 		ereport(FATAL,
@@ -786,7 +806,7 @@ Pgversion(POOL_CONNECTION_POOL * backend)
 	{
 		p++;
 		i = 0;
-		while (i < VERSION_BUF_SIZE -1 && p && *p != '.' && *p != ' ')
+		while (i < VERSION_BUF_SIZE - 1 && p && *p != '.' && *p != ' ')
 		{
 			buf[i++] = *p++;
 		}
@@ -802,7 +822,7 @@ Pgversion(POOL_CONNECTION_POOL * backend)
 	 */
 	p++;
 	i = 0;
-	while (i < VERSION_BUF_SIZE -1 && p && *p != '.' && *p != ' ')
+	while (i < VERSION_BUF_SIZE - 1 && p && *p != '.' && *p != ' ')
 	{
 		buf[i++] = *p++;
 	}
@@ -864,6 +884,7 @@ choose_db_node_id(char *str)
 	}
 	return node_id;
 }
+
 /*
  *---------------------------------------------------------------------------------
  * Snapshot Isolation modules
@@ -988,7 +1009,7 @@ void
 si_snapshot_acquired(void)
 {
 	POOL_SESSION_CONTEXT *session;
-	int		i;
+	int			i;
 
 	session = pool_get_session_context(true);
 
@@ -1003,9 +1024,10 @@ si_snapshot_acquired(void)
 		if (si_manage_info->snapshot_counter == 0)
 		{
 			/* wakeup all waiting children */
-			for (i = 0; i < pool_config->num_init_children ; i++)
+			for (i = 0; i < pool_config->num_init_children; i++)
 			{
-				pid_t pid = si_manage_info->snapshot_waiting_children[i];
+				pid_t		pid = si_manage_info->snapshot_waiting_children[i];
+
 				if (pid > 0)
 				{
 					elog(SI_DEBUG_LOG_LEVEL, "si_snapshot_acquired: send SIGUSR2 to %d", pid);
@@ -1061,7 +1083,7 @@ void
 si_commit_done(void)
 {
 	POOL_SESSION_CONTEXT *session;
-	int		i;
+	int			i;
 
 	session = pool_get_session_context(true);
 
@@ -1077,9 +1099,10 @@ si_commit_done(void)
 		if (si_manage_info->commit_counter == 0)
 		{
 			/* wakeup all waiting children */
-			for (i = 0; i < pool_config->num_init_children ; i++)
+			for (i = 0; i < pool_config->num_init_children; i++)
 			{
-				pid_t pid = si_manage_info->commit_waiting_children[i];
+				pid_t		pid = si_manage_info->commit_waiting_children[i];
+
 				if (pid > 0)
 				{
 					elog(SI_DEBUG_LOG_LEVEL, "si_commit_done: send SIGUSR2 to %d", pid);
@@ -1102,7 +1125,8 @@ si_commit_done(void)
  * -1: delay exceeds delay_threshold_by_time
  * -2: delay exceeds delay_threshold
  */
-int	check_replication_delay(int node_id)
+int
+check_replication_delay(int node_id)
 {
 	BackendInfo *bkinfo;
 
@@ -1117,7 +1141,7 @@ int	check_replication_delay(int node_id)
 	 * to multiply delay_threshold_by_time by 1000 to normalize.
 	 */
 	if (pool_config->delay_threshold_by_time > 0 &&
-		bkinfo->standby_delay > pool_config->delay_threshold_by_time*1000)
+		bkinfo->standby_delay > pool_config->delay_threshold_by_time * 1000)
 		return -1;
 
 	/*
@@ -1129,4 +1153,3 @@ int	check_replication_delay(int node_id)
 
 	return 0;
 }
-
