@@ -3,7 +3,8 @@
  * pgpool_adm.h
  *
  *
- * Copyright (c) 2002-2018, PostgreSQL Global Development Group
+ * Copyright (c) 2002-2025, PostgreSQL Global Development Group
+ * Copyright (c) 2019-2025, PgPool Global Development Group
  *
  * Author: Jehan-Guillaume (ioguix) de Rorthais <jgdr@dalibo.com>
  *
@@ -25,6 +26,7 @@ Datum		_pcp_pool_status(PG_FUNCTION_ARGS);
 Datum		_pcp_node_count(PG_FUNCTION_ARGS);
 Datum		_pcp_attach_node(PG_FUNCTION_ARGS);
 Datum		_pcp_detach_node(PG_FUNCTION_ARGS);
+Datum		_pcp_proc_info(PG_FUNCTION_ARGS);
 
 PG_FUNCTION_INFO_V1(_pcp_node_info);
 PG_FUNCTION_INFO_V1(_pcp_health_check_stats);
@@ -32,5 +34,6 @@ PG_FUNCTION_INFO_V1(_pcp_pool_status);
 PG_FUNCTION_INFO_V1(_pcp_node_count);
 PG_FUNCTION_INFO_V1(_pcp_attach_node);
 PG_FUNCTION_INFO_V1(_pcp_detach_node);
+PG_FUNCTION_INFO_V1(_pcp_proc_info);
 
 #endif
